-- $Id: data.lua 2 2022-11-13 08:14:04Z arithmandar $
-----------------------------------------------------------------------
-- Upvalued Lua API.
-----------------------------------------------------------------------
local _G = getfenv(0)
local select = _G.select
local string = _G.string
local format = string.format

-- WoW
local GetAchievementInfo = GetAchievementInfo
-- ----------------------------------------------------------------------------
-- AddOn namespace.
-- ----------------------------------------------------------------------------
local addonname = ...
local AtlasLoot = _G.AtlasLoot
local data = AtlasLoot.ItemDB:Add(addonname, 10)

local moduleMeta = {
		addonName = addonname,
		icon = "Interface\\ICONS\\achievement_mythicdungeons_shadowlands",
		name = EXPANSION_NAME9,
		tt_title = nil,		-- ToolTip title
		tt_text = nil,		-- ToolTip text
}

AtlasLoot:RegisterModules(addonname, moduleMeta)

local AL = AtlasLoot.Locales

local RF_DIFF = data:AddDifficulty(AL["Raid Finder"], "LFRWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 17)
local NORMAL_DIFF = data:AddDifficulty(AL["Normal"], "n", {
	Item = {
		item1bonus = "Scaling",
		addDifficultyBonus = true,
	},
}, 1)
local NORMAL_RAID_DIFF = data:AddDifficulty(AL["Normal"], "NormalRaidWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 14)
local NORMAL_DUNGEON_DIFF = data:AddDifficulty(AL["Normal"], "DungeonWithPreset", {
	Item = {
		item1bonus = "Scaling",
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 1)
local HEROIC_DIFF = data:AddDifficulty(AL["Heroic"], "h", nil, 2)
local HEROIC_DUNGEON_DIFF = data:AddDifficulty(AL["Heroic"], "HeroicDungeonWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl", --"BfAHCDungeonTitanforged",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 2)
local MYTHICD_DIFF = data:AddDifficulty(AL["Mythic"], "h", nil, 23)
local MYTHICD_DUNGEON_DIFF = data:AddDifficulty(AL["Mythic"], "MythicDungeonWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 23)
local MYTHICD2_DIFF = data:AddDifficulty(AL["Mythic"], "h", nil, 23)
local MYTHICD2_DUNGEON_DIFF = data:AddDifficulty(AL["Mythic"], "MythicDungeon2WithPreset", {
	Item = {
		item1bonus = "LegionMDungeon2",
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 23)
local HEROIC_PRE_DIFF = data:AddDifficulty(AL["Heroic"], "HeroicWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 15)
local MYTHIC_DIFF = data:AddDifficulty(AL["Mythic"], "m", nil, 16)
local MYTHIC_PRE_DIFF = data:AddDifficulty(AL["Mythic"], "MyhticWithPreset", {
	Item = {
		item2bonus = "BfAMaxItemLvl",
		autoCompleteItem2 = true,
		addDifficultyBonus = true,
	},
}, 16)

local NORMAL_ITTYPE = data:AddItemTableType("Item", "Item")
local RAID_ITTYPE = data:AddItemTableType("Item", "Item") -- Normal, Thunder-/Warforged...
local AC_ITTYPE = data:AddItemTableType("Achievement", "Item")

local DUNGEON_CONTENT = data:AddContentType(AL["Dungeons"], ATLASLOOT_DUNGEON_COLOR)
local RAID_CONTENT = data:AddContentType(AL["Raids"], ATLASLOOT_RAID_COLOR)


-- /////////////////////////////////
-- Instance
-- /////////////////////////////////
--[[
data["InstanceName"] = {
	EncounterJournalID = 111,
	MapID = 749,
	ContentType = DUNGEON_CONTENT / RAID_CONTENT,
	TableType = RAID_ITTYPE,
	items = 
	{
		{ -- bossN
			EncounterJournalID = 1111,
			[NORMAL_RAID_DIFF] = {
			},
		},
	}
}
]]
data["Algeth'ar Academy"] = {
	EncounterJournalID = 1201,
	MapID = 2097,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Vexamus
			EncounterJournalID = 2509,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193708 }, --Platinum Star Band
				{ 2, 193710 }, --Spellboon Saber
				{ 3, 193709 }, --Vexamus' Expulsion Rod
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Overgrown Ancient
			EncounterJournalID = 2512,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193712 }, --Potion-Stained Cloak
				{ 2, 193713 }, --Experimental Safety Gloves
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Crawth
			EncounterJournalID = 2495,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193720 }, -- Bronze Challenger's Robe
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Echo of Doragosa
			EncounterJournalID = 2514,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193707 }, --Final Grade
				{ 2, 198056 }, --Titan Training Matrix II
				{ 1, 193703 }, --Organized Pontificator's Mask
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193707 }, --Final Grade
				{ 2, 198058 }, --Titan Training Matrix III
				{ 3, 193703 }, --Organized Pontificator's Mask
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193707 }, --Final Grade
				{ 2, 198059 }, --Titan Training Matrix IV
				{ 3, 193703 }, --Organized Pontificator's Mask
			},
		},
	}
}

data["Brackenhide Hollow"] = {
	EncounterJournalID = 1196,
	MapID = 2096,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Hackclaw's War-Band
			EncounterJournalID = 2471,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193673 }, --Ravenous Pursuer's Footwraps
				{ 2, 193671 }, --Bloodied Wedding Ring
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Treemouth
			EncounterJournalID = 2473,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193653 }, -- ask of Imperishable Leaves
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Gutshot
			EncounterJournalID = 2472,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193666 }, -- Tuskarr Bone Necklace
				{ 2, 193667 }, -- Boastful Stalker's Epaulets
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Decatriarch Wratheye
			EncounterJournalID = 2474,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 198056 }, --Titan Training Matrix II
				{ 2, 193660 }, --Idol of Pure Decay
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 198058 }, --Titan Training Matrix III
				{ 2, 193660 }, --Idol of Pure Decay
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 198059 }, --Titan Training Matrix IV
				{ 2, 193660 }, --Idol of Pure Decay
			},
		},
	}
}

data["Halls of Infusion"] = {
	EncounterJournalID = 1204,
	MapID = 2082,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Watcher Irideus
			EncounterJournalID = 2504,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193745 }, --Rod of Perfect Order
				{ 2, 193743 }, --Irideus Fragment
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Gulping Goliath
			EncounterJournalID = 2507,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193724 }, --Lily-Laced Bracelets
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Khajin the Unyielding
			EncounterJournalID = 2510,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193733 }, --Khajin's Hailstone Footwraps
				{ 2, 193731 }, --Circle of Ascended Frost
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Primal Tsunami
			EncounterJournalID = 2511,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 198056 }, --Titan Training Matrix II
				{ 2, 193738 }, --Robe of Plunging Depths
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 198058 }, --Titan Training Matrix III
				{ 2, 193738 }, --Robe of Plunging Depths
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 198059 }, --Titan Training Matrix IV
				{ 2, 193738 }, --Robe of Plunging Depths
			},
		},
	}
}

data["Neltharus"] = {
	EncounterJournalID = 1199,
	MapID = 2080,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Chargath, Bane of Scales
			EncounterJournalID = 2490,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193768 }, --Scalebane Signet
				{ 2, 193769 }, --Erupting Spear Fragment
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Forgemaster Gorek
			EncounterJournalID = 2489,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193783 }, --Irontorch Igniter
				{ 2, 193780 }, --Flare-Singed Strap
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Magmatusk
			EncounterJournalID = 2494,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193788 }, --Molten Magma Mantle
				{ 2, 193790 }, --Searing Tusk Shard
				{ 3, 193787 }, --Mammoth-Trainer's Drape
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Warlord Sargha
			EncounterJournalID = 2501,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193773 }, --Spoils of Neltharus
				{ 2, 193775 }, --Warlord's Cindermitts
				{ 3, 198056 }, --Titan Training Matrix II
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193773 }, --Spoils of Neltharus
				{ 2, 193775 }, --Warlord's Cindermitts
				{ 3, 198058 }, --Titan Training Matrix III
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193773 }, --Spoils of Neltharus
				{ 2, 193775 }, --Warlord's Cindermitts
				{ 3, 198059 }, --Titan Training Matrix IV
			},
		},
	}
}

data["Ruby Life Pools"] = {
	EncounterJournalID = 1202,
	MapID = 2095,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Melidrussa Chillworn
			EncounterJournalID = 2488,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193761 }, --Chillworn's Infusion Staff
				{ 2, 193757 }, --Ruby Whelp Shell
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Kokia Blazehoof
			EncounterJournalID = 2485,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193766 }, --Kokia's Burnout Rod
				{ 2, 193763 }, --Fireproof Drape
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Kyrakka and Erkhart Stormvein
			EncounterJournalID = 2503,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193691 }, --Sky Saddle Cord
				{ 2, 193750 }, --Wind Soarer's Breeches
				{ 3, 198056 }, --Titan Training Matrix II
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193691 }, --Sky Saddle Cord
				{ 2, 193750 }, --Wind Soarer's Breeches
				{ 3, 198058 }, --Titan Training Matrix III
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193691 }, --Sky Saddle Cord
				{ 2, 193750 }, --Wind Soarer's Breeches
				{ 3, 198059 }, --Titan Training Matrix IV
			},
		},
	}
}

data["The Azure Vault"] = {
	EncounterJournalID = 1203,
	MapID = 2073,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Leymor
			EncounterJournalID = 2492,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193635 }, --Infused Elemental Bands
				{ 2, 193633 }, --Unstable Arcane Loop
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Azureblade
			EncounterJournalID = 2494,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193629 }, --Cloak of Lost Devotion
				{ 2, 193628 }, --Tome of Unstable Power
				{ 3, 193632 }, --Tz'onna, Fear-Striker
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Telash Greywing
			EncounterJournalID = 2483,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193647 }, --Custodian's Medallion of Delusion
				{ 2, 193648 }, --Azureblade's Work Gloves
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Umbrelskul
			EncounterJournalID = 2508,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193639 }, --Umbrelskul's Fractured Heart
				{ 2, 193641 }, --Headwrap of the Abandoned
				{ 3, 198056 }, --Titan Training Matrix II
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193639 }, --Umbrelskul's Fractured Heart
				{ 2, 193641 }, --Headwrap of the Abandoned
				{ 3, 198058 }, --Titan Training Matrix III
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193639 }, --Umbrelskul's Fractured Heart
				{ 2, 193641 }, --Headwrap of the Abandoned
				{ 3, 198059 }, --Titan Training Matrix IV
			},
		},
	}
}

data["The Nokhud Offensive"] = {
	EncounterJournalID = 1198,
	MapID = 2093,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- Granyth
			EncounterJournalID = 2498,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193690 }, --Drake Hunter Shoulderpads
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- The Raging Tempest
			EncounterJournalID = 2497,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193699 }, --Staff of Violent Storms
				{ 2, 193696 }, --Thunderous Downburst Ring
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Teera and Maruuk
			EncounterJournalID = 2478,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193676 }, --Ukhel Ancestry Beads
				{ 2, 193677 }, --Furious Ragefeather
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Balakar Khan
			EncounterJournalID = 2477,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193683 }, --Blessed Ohn'ir Robes
				{ 2, 193687 }, --Koroleth's Crackling Dagger
				{ 3, 198056 }, --Titan Training Matrix II
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193683 }, --Blessed Ohn'ir Robes
				{ 2, 193687 }, --Koroleth's Crackling Dagger
				{ 3, 198058 }, --Titan Training Matrix III
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193683 }, --Blessed Ohn'ir Robes
				{ 2, 193687 }, --Koroleth's Crackling Dagger
				{ 3, 198059 }, --Titan Training Matrix IV
			},
		},
	}
}

data["Uldaman: Legacy of Tyr"] = {
	EncounterJournalID = 1197,
	MapID = 2071,
	--AtlasMapID = "",
	ContentType = DUNGEON_CONTENT,
	items = 
	{
		{ -- The Lost Dwarves
			EncounterJournalID = 2475,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193816 }, --Lost Hero's Waist Wrap
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Bromach
			EncounterJournalID = 2487,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193809 }, --Bromach's Disentombed Locket
				{ 2, 193810 }, --Miner's Sturdy Trousers
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Sentinel Talondras
			EncounterJournalID = 2484,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193806 }, --Ancient Crosswrapped Sandals
				{ 2, 193804 }, --Eternal Sentry's Ring
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Emberon
			EncounterJournalID = 2476,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193792 }, --Animated Shackles
			},
			[HEROIC_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
			[MYTHICD_DUNGEON_DIFF] = {
				GetItemsFromDiff = NORMAL_DUNGEON_DIFF,
			},
		},
		{ -- Chrono-Lord Deios
			EncounterJournalID = 2479,
			[NORMAL_DUNGEON_DIFF] = {
				{ 1, 193791 }, --Time-Breaching Talon
				{ 2, 193799 }, --Crazed Traveler's Legwraps
				{ 3, 193803 }, --Infinite Dragonspire
				{ 4, 198056 }, --Titan Training Matrix II
			},
			[HEROIC_DUNGEON_DIFF] = {
				{ 1, 193791 }, --Time-Breaching Talon
				{ 2, 193799 }, --Crazed Traveler's Legwraps
				{ 3, 193803 }, --Infinite Dragonspire
				{ 4, 198058 }, --Titan Training Matrix III
			},
			[MYTHICD_DUNGEON_DIFF] = {
				{ 1, 193791 }, --Time-Breaching Talon
				{ 2, 193799 }, --Crazed Traveler's Legwraps
				{ 3, 193803 }, --Infinite Dragonspire
				{ 4, 198059 }, --Titan Training Matrix IV
			},
		},
	}
}

-- /////////////////////////////////
-- Raid
-- /////////////////////////////////

data["Dragon Isles"] = {
	EncounterJournalID = 1205,
	MapID = 1978,
	ContentType = RAID_CONTENT,
	TableType = RAID_ITTYPE,
	items = 
	{
		{ -- Strunraan, The Sky's Misery
			EncounterJournalID = 2515,
			[NORMAL_RAID_DIFF] = {
				{ 1, 200687 }, --Stormshale Cuffs
				{ 2, 200676 }, --Static-Charged Scale
			},
		},
		{ -- Liskanoth, The Futurebane
			EncounterJournalID = 2518,
			[NORMAL_RAID_DIFF] = {
				{ 1, 200763 }, --Frosted Scale Drape
				{ 2, 200743 }, --Frozen Footwraps
			},
		},
		{ -- Bazual, The Dreaded Flame
			EncounterJournalID = 2517,
			[NORMAL_RAID_DIFF] = {
				{ 1, 200654 }, --Magmatic Vestments
				{ 2, 200761 }, --Smoldering Sulfuron Signet
			},
		},
		{ -- Basrikron, The Shale Wing
			EncounterJournalID = 2506,
			[NORMAL_RAID_DIFF] = {
				{ 1, 200762 }, --Earthspeaker's Brooch
				{ 1, 200736 }, --Belt of Living Earth
			},
		},
	}
}

data["Vault of the Incarnates"] = {
	EncounterJournalID = 1200,
	MapID = 2119,
	ContentType = RAID_CONTENT,
	TableType = RAID_ITTYPE,
	items = 
	{
		{ -- Dathea, Ascended
			EncounterJournalID = 2502,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195493 }, --Ascended Squallspires
				{ 2, 196597 }, --Mystic Garnet Forgestone
				{ 3, 195496 }, --Eye of the Vengeful Hurricane
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- The Primal Council
			EncounterJournalID = 2486,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195484 }, --Icewrath's Channeling Conduit
				{ 2, 194301 }, --Whispering Incarnate Icon
				{ 3, 195485 }, --Councilor's Terrormask
				{ 4, 194300 }, --Conjured Chillglobe
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Raszageth the Storm-Eater
			EncounterJournalID = 2499,
			[NORMAL_RAID_DIFF] = {
				{ 1, 194309 }, --Spiteful Storm
				{ 2, 194310 }, --Desperate Invoker's Codex
				{ 3, 196600 }, --Mystic Topaz Forgestone
				{ 4, 195532 }, --Sandals of the Wild Sovereign
				{ 5, 195529 }, --Stormlash's Last Resort
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Broodkeeper Diurna
			EncounterJournalID = 2493,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195523 }, --Eggtender's Safety Mitts
				{ 2, 196599 }, --Mystic Lapis Forgestone
				{ 3, 195526 }, --Seal of Filial Duty
				{ 4, 194307 }, --Broodkeeper's Promise
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Kurog Grimtotem
			EncounterJournalID = 2491,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195513 }, --Scripture of Primal Devotion
				{ 2, 195515 }, --Magatha's Spiritual Sash
				{ 3, 196596 }, --Mystic Amethyst Forgestone
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Sennarth, the Cold Breath
			EncounterJournalID = 2482,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195511 }, --Acid-Proof Webbing
				{ 2, 194304 }, --Iceblood Deathsnare
				{ 3, 196598 }, --Mystic Jade Forgestone
				{ 4, 195508 }, --Chilled Silken Restraints
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Terros
			EncounterJournalID = 2500,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195502 }, --Terros's Captive Core
				{ 2, 195497 }, --Quake-Detecting Seismostaff
				{ 3, 195500 }, --Compressed Cultist's Frock
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
		{ -- Eranog
			EncounterJournalID = 2480,
			[NORMAL_RAID_DIFF] = {
				{ 1, 195480 }, --Seal of Diurna's Chosen
				{ 2, 195479 }, --Flametender's Legwraps
				{ 3, 195482 }, --Decorated Commander's Cindercloak
			},
			[HEROIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[MYTHIC_PRE_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
			[RF_DIFF] = {
				GetItemsFromDiff = NORMAL_RAID_DIFF,
			},
		},
	}
}
